from .__init__ import ctypes, \
    SDL_FUNC, SDL_SET_CURRENT_DLL, SDL_DLL

from .SDL_video import SDL_Window

SDL_SET_CURRENT_DLL(SDL_DLL)

class SDL_DialogFileFilter(ctypes.Structure):
    _fields_ = [
        ("name", ctypes.c_char_p),
        ("pattern", ctypes.c_char_p)
    ]

SDL_DialogFileCallback = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.POINTER(ctypes.c_char_p), ctypes.c_int)

SDL_FUNC("SDL_ShowOpenFileDialog", None, SDL_DialogFileCallback, ctypes.c_void_p, ctypes.POINTER(SDL_Window), ctypes.POINTER(SDL_DialogFileFilter), ctypes.c_int, ctypes.c_char_p, ctypes.c_bool)
SDL_FUNC("SDL_ShowSaveFileDialog", None, SDL_DialogFileCallback, ctypes.c_void_p, ctypes.POINTER(SDL_Window), ctypes.POINTER(SDL_DialogFileFilter), ctypes.c_int, ctypes.c_char_p)
SDL_FUNC("SDL_ShowOpenFolderDialog", None, SDL_DialogFileCallback, ctypes.c_void_p, ctypes.POINTER(SDL_Window), ctypes.c_char_p, ctypes.c_bool)


import setuptools, sys, os

from setuptools.dist import Distribution
from setuptools.command.install import install

class CustomInstall(install):
    def __init__(self, dist: Distribution) -> None:
        super(install, self).__init__(dist)
        
    def run(self) -> None:
        super(install, self).run()

        if sys.platform in ["win32"]:
            os.environ["PYSDL3_DISABLE_DOCS"] = "0"
            print("generating '__docs__.py'.", flush = True)
            sdl3 = __import__("sdl3")
            loaded = sum(len(v) for k, v in sdl3.functions.items())

            if loaded > 0:
                print(f"loaded {loaded} functions.", flush = True)

            else:
                print("something went wrong.", flush = True)

def main(argv):
    data = {
        "name": "PySDL3",
        "packages": ["sdl3", "sdl3.bin"],
        "version": "0.5.0a0",
        "description": "A pure Python wrapper for SDL3.",
        "long_description": open("README.md", "r", encoding = "utf-8").read(),
        "long_description_content_type": "text/markdown",
        "url": "https://github.com/Aermoss/PySDL3",
        "download_url": "https://pypi.python.org/pypi/PySDL3",
        "author": "Yusuf Rençber",
        "author_email": "aermoss.0@gmail.com",
        "license": "MIT",
        "include_package_data": True,
        "install_requires": [],
        "cmdclass": {"install": CustomInstall},
        "classifiers": [
            "Development Status :: 3 - Alpha",
            "Intended Audience :: Developers",
            "License :: OSI Approved :: MIT License",
            "Operating System :: Microsoft :: Windows",
            "Programming Language :: Python :: 3.9",
            "Programming Language :: Python :: 3.10",
            "Programming Language :: Python :: 3.11",
            "Programming Language :: Python :: 3.12",
            "Programming Language :: Python :: 3.13",
            "Programming Language :: Python :: 3.14",
            "Topic :: Software Development :: Libraries :: Python Modules"
        ]
    }

    setuptools.setup(**data)

if __name__ == "__main__":
    sys.exit(main(sys.argv))